@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Compute the affinity between two people
 
-our $VERSION = '0.0101';
+our $VERSION = '0.0102';
 
 use Moo;
 use strictures 2;
@@ -73,17 +73,21 @@ sub score {
 sub _score {
     my ( $me, $you, $importance ) = @_;
 
-    my $me_score = 0;
-    my $me_total = 0;
+    my $score = 0;
+    my $total = 0;
+
     for my $i ( 0 .. @$me - 1 ) {
-        $me_total += $importance->{ $me->[$i][2] };
+        $total += $importance->{ $me->[$i][2] };
+
         if ( $me->[$i][1] eq $you->[$i][0] ) {
-            $me_score += $importance->{ $me->[$i][2] };
+            $score += $importance->{ $me->[$i][2] };
         }
     }
-    $me_score /= $me_total;
 
-    return $me_score;
+    $score /= $total
+        if $total != 0;
+
+    return $score;
 }
 
 1;
@@ -100,12 +104,12 @@ Acme::Affinity - Compute the affinity between two people
 
 =head1 VERSION
 
-version 0.0101
+version 0.0102
 
 =head1 SYNOPSIS
 
   use Acme::Affinity;
-  my %arguments = ( questions => [], importance => [], me => [], you => [] );
+  my %arguments = ( questions => [], importance => {}, me => [], you => [] );
   my $affinity = Acme::Affinity->new(%arguments);
   my $score = $affinity->score();
 
